@@ -9,16 +9,16 @@ import xml.etree.ElementTree as ET
 SCRIPTS_DIR = os.path.dirname(os.path.realpath(__file__))
 ROOT_DIR = os.path.dirname(SCRIPTS_DIR)
 DATA_DIR = os.path.join(ROOT_DIR, "data")
-TEMPLATE_METAINFO_XML_FILEPATH = os.path.join(DATA_DIR, "_com.giuspen.cherrytree.metainfo.xml")
-METAINFO_XML_FILEPATH = os.path.join(DATA_DIR, "com.giuspen.cherrytree.metainfo.xml")
+TEMPLATE_METAINFO_XML_FILEPATH = os.path.join(DATA_DIR, "_net.giuspen.cherrytree.metainfo.xml")
+METAINFO_XML_FILEPATH = os.path.join(DATA_DIR, "net.giuspen.cherrytree.metainfo.xml")
 DEBIAN_CHANGELOG_PATH = os.path.join(ROOT_DIR, "debian", "changelog")
 
 VERSION = "?"
-with open(DEBIAN_CHANGELOG_PATH, "r") as fd:
+with open(DEBIAN_CHANGELOG_PATH, "rb") as fd:
     for fileline in fd:
-        match = re.search(r"cherrytree +\(([0-9]+\.[0-9]+\.[0-9]+)[-+]", fileline)
+        match = re.search(b"cherrytree +\(([0-9]+\.[0-9]+\.[0-9]+)[-+]", fileline)
         if match is not None:
-            VERSION = match.group(1)
+            VERSION = str(match.group(1))
             #print(VERSION)
             break
 DATE = time.strftime(
