@@ -126,11 +126,11 @@ void CtActions::embfile_delete()
 
 void CtActions::embfile_save()
 {
-    CtDialogs::FileSelectArgs args{_pCtMainWin};
+    CtDialogs::CtFileSelectArgs args{};
     args.curr_folder = _pCtConfig->pickDirFile;
     args.curr_file_name = curr_file_anchor->get_file_name();
 
-    std::string filepath = CtDialogs::file_save_as_dialog(args);
+    std::string filepath = CtDialogs::file_save_as_dialog(_pCtMainWin, args);
     if (filepath.empty()) return;
 
     _pCtConfig->pickDirFile = Glib::path_get_dirname(filepath);
@@ -182,13 +182,13 @@ void CtActions::embfile_rename()
 
 void CtActions::latex_save()
 {
-    CtDialogs::FileSelectArgs args{_pCtMainWin};
+    CtDialogs::CtFileSelectArgs args{};
     args.curr_folder = _pCtConfig->pickDirImg;
     args.curr_file_name = "";
     args.filter_name = _("PNG Image");
     args.filter_pattern = {"*.png"};
 
-    std::string filename = CtDialogs::file_save_as_dialog(args);
+    std::string filename = CtDialogs::file_save_as_dialog(_pCtMainWin, args);
     if (filename.empty()) return;
 
     _pCtConfig->pickDirImg = Glib::path_get_dirname(filename);
@@ -232,13 +232,13 @@ void CtActions::latex_delete()
 
 void CtActions::image_save()
 {
-    CtDialogs::FileSelectArgs args{_pCtMainWin};
+    CtDialogs::CtFileSelectArgs args{};
     args.curr_folder = _pCtConfig->pickDirImg;
     args.curr_file_name = "";
     args.filter_name = _("PNG Image");
     args.filter_pattern = {"*.png"};
 
-    std::string filename = CtDialogs::file_save_as_dialog(args);
+    std::string filename = CtDialogs::file_save_as_dialog(_pCtMainWin, args);
     if (filename.empty()) return;
 
     _pCtConfig->pickDirImg = Glib::path_get_dirname(filename);
@@ -553,7 +553,8 @@ void CtActions::_exec_code(const bool is_all)
         _pCtMainWin->exec_in_vte(binary_cmd);
     }
     else {
-        (void)std::system(terminal_cmd.c_str());
+        const int retVal = std::system(terminal_cmd.c_str());
+        if (retVal != 0) spdlog::error("system({}) returned {}", terminal_cmd, retVal);
     }
 }
 
@@ -561,10 +562,10 @@ void CtActions::codebox_load_from_file()
 {
     if (not _is_there_anch_widg_selection_or_error('c')) return;
     if (not _is_curr_node_not_read_only_or_error()) return;
-    CtDialogs::FileSelectArgs args{_pCtMainWin};
+    CtDialogs::CtFileSelectArgs args{};
     args.curr_folder = _pCtConfig->pickDirCbox;
 
-    std::string filepath = CtDialogs::file_select_dialog(args);
+    std::string filepath = CtDialogs::file_select_dialog(_pCtMainWin, args);
     if (filepath.empty()) return;
     _pCtConfig->pickDirCbox = Glib::path_get_dirname(filepath);
 
@@ -575,10 +576,10 @@ void CtActions::codebox_load_from_file()
 void CtActions::codebox_save_to_file()
 {
     if (not _is_there_anch_widg_selection_or_error('c')) return;
-    CtDialogs::FileSelectArgs args{_pCtMainWin};
+    CtDialogs::CtFileSelectArgs args{};
     args.curr_folder=_pCtConfig->pickDirCbox;
 
-    std::string filepath = CtDialogs::file_save_as_dialog(args);
+    std::string filepath = CtDialogs::file_save_as_dialog(_pCtMainWin, args);
     if (filepath.empty()) return;
     _pCtConfig->pickDirCbox = Glib::path_get_dirname(filepath);
 
@@ -833,13 +834,13 @@ void CtActions::table_edit_properties()
 void CtActions::table_export()
 {
     if (not _is_there_anch_widg_selection_or_error('t')) return;
-    CtDialogs::FileSelectArgs args{_pCtMainWin};
+    CtDialogs::CtFileSelectArgs args{};
     args.curr_folder = _pCtConfig->pickDirCsv;
     args.curr_file_name = "";
     args.filter_name = _("CSV File");
     args.filter_pattern = {"*.csv"};
 
-    Glib::ustring filename = CtDialogs::file_save_as_dialog(args);
+    Glib::ustring filename = CtDialogs::file_save_as_dialog(_pCtMainWin, args);
     if (filename.empty()) return;
     if (!str::endswith(filename, ".csv")) filename += ".csv";
     _pCtConfig->pickDirCsv = Glib::path_get_dirname(filename);
@@ -882,7 +883,7 @@ bool CtActions::_on_embfiles_sentinel_timeout()
         }
         if (item.second.mod_time != fs::getmtime(tmp_filepath)) {
             item.second.mod_time = fs::getmtime(tmp_filepath);
-            const auto data_vec = str::split(tmp_filepath.filename().string(), CtConst::CHAR_MINUS);
+            const auto data_vec = str::split(tmp_filepath.filename().string(), "-");
             const gint64 node_id = std::stoll(data_vec[0]);
             const size_t embfile_id = std::stol(data_vec[1]);
 
@@ -904,7 +905,7 @@ bool CtActions::_on_embfiles_sentinel_timeout()
                         embFile->update_tooltip();
 
                         _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf);
-                        _pCtMainWin->get_status_bar().update_status(_("Embedded File Automatically Updated:") + std::string(CtConst::CHAR_SPACE) + embFile->get_file_name().string());
+                        _pCtMainWin->get_status_bar().update_status(_("Embedded File Automatically Updated:") + CtConst::CHAR_SPACE + embFile->get_file_name().string());
                         break;
                     }
                 }
