@@ -1,7 +1,7 @@
 /*
  * ct_actions_view.cc
  *
- * Copyright 2009-2022
+ * Copyright 2009-2023
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -26,7 +26,19 @@
 #include <gtkmm/stock.h>
 #include "ct_dialogs.h"
 
-// Toggle Show/Hide the Tree
+void CtActions::toggle_show_hide_vte()
+{
+    _pCtConfig->vteVisible = not _pCtMainWin->is_vte_visible();
+    (void)_pCtMainWin->show_hide_vte_cmd_passed_as_first_in_session(_pCtConfig->vteVisible, nullptr/*first_cmd_passed*/);
+    if (_pCtConfig->vteVisible) {
+        Gtk::Widget* pVte = _pCtMainWin->get_vte();
+        if (pVte) pVte->grab_focus();
+    }
+    else {
+        _pCtMainWin->get_text_view().grab_focus();
+    }
+}
+
 void CtActions::toggle_show_hide_tree()
 {
     _pCtConfig->treeVisible = not _pCtConfig->treeVisible;
@@ -75,51 +87,63 @@ void CtActions::toggle_show_hide_tree_lines()
     _pCtMainWin->show_hide_tree_lines(_pCtConfig->treeLinesVisible);
 }
 
-// Toggle Focus Between Tree and Text
-void CtActions::toggle_tree_text()
+void CtActions::toggle_focus_tree_text()
 {
-    if (_pCtMainWin->get_tree_view().has_focus())
+    if (_pCtMainWin->get_tree_view().has_focus()) {
         _pCtMainWin->get_text_view().grab_focus();
-    else
+    }
+    else {
         _pCtMainWin->get_tree_view().grab_focus();
+    }
+}
+
+void CtActions::toggle_focus_vte_text()
+{
+    if (_pCtMainWin->is_vte_visible() and _pCtMainWin->get_text_view().has_focus()) {
+        Gtk::Widget* pVte = _pCtMainWin->get_vte();
+        if (pVte) pVte->grab_focus();
+    }
+    else {
+        _pCtMainWin->get_text_view().grab_focus();
+    }
 }
 
-// Expand all Tree Nodes
 void CtActions::nodes_expand_all()
 {
     _pCtMainWin->get_tree_view().expand_all();
 }
 
-// Collapse all Tree Nodes
 void CtActions::nodes_collapse_all()
 {
     _pCtMainWin->get_tree_view().collapse_all();
 }
 
-// Increase the Size of the Toolbar Icons
 void CtActions::toolbar_icons_size_increase()
 {
     if (_pCtConfig->toolbarIconSize == 5) {
-        CtDialogs::info_dialog(_("The Size of the Toolbar Icons is already at the Maximum Value"), *_pCtMainWin);
+        CtDialogs::info_dialog(_("The Size of the Toolbar Icons is already at the Maximum Value."), *_pCtMainWin);
         return;
     }
     _pCtConfig->toolbarIconSize += 1;
     _pCtMainWin->set_toolbars_icon_size(_pCtConfig->toolbarIconSize);
 }
 
-// Decrease the Size of the Toolbar Icons
 void CtActions::toolbar_icons_size_decrease()
 {
     if (_pCtConfig->toolbarIconSize == 1) {
-        CtDialogs::info_dialog(_("The Size of the Toolbar Icons is already at the Minimum Value"), *_pCtMainWin);
+        CtDialogs::info_dialog(_("The Size of the Toolbar Icons is already at the Minimum Value."), *_pCtMainWin);
         return;
     }
     _pCtConfig->toolbarIconSize -= 1;
     _pCtMainWin->set_toolbars_icon_size(_pCtConfig->toolbarIconSize);
 }
 
-// Toggle Fullscreen State
-void CtActions::fullscreen_toggle()
+void CtActions::toggle_always_on_top()
+{
+    _pCtMainWin->toggle_always_on_top();
+}
+
+void CtActions::toggle_fullscreen()
 {
     if (_pCtMainWin->get_titlebar()) {
         // unfullscreen doesn't work with the custom titlebar, so we can only maximise
@@ -143,5 +167,5 @@ void CtActions::fullscreen_toggle()
 void CtActions::_menubar_in_titlebar_set(const bool setOn)
 {
     _pCtConfig->menubarInTitlebar = setOn;
-    CtDialogs::info_dialog(_("This Change will have Effect Only After Restarting CherryTree"), *_pCtMainWin);
+    CtDialogs::info_dialog(_("This Change will have Effect Only After Restarting CherryTree."), *_pCtMainWin);
 }
