@@ -1,7 +1,7 @@
 /*
  * ct_column_edit.h
  *
- * Copyright 2009-2022
+ * Copyright 2009-2023
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -36,6 +36,11 @@ class CtColumnEdit
 public:
     CtColumnEdit(Gtk::TextView& textView);
 
+    CtColEditState get_state() const { return _state; }
+    Glib::ustring copy() const;
+    Glib::ustring cut();
+    void paste(const std::string& column_txt);
+
     void selection_update();
     void button_control_changed(const bool isDown) { _ctrlDown = isDown; }
     void button_alt_changed(const bool isDown) { _altDown = isDown; }
@@ -43,9 +48,9 @@ public:
     void text_inserted(const Gtk::TextIter& pos, const Glib::ustring& text);
     void text_removed(const Gtk::TextIter& range_start, const Gtk::TextIter& range_end);
     void column_mode_off();
-    bool ctrl_down() { return _ctrlDown; }
-    bool alt_down() { return _altDown; }
-    bool own_insert_delete_active() { return _myOwnInsertDelete; }
+    bool get_ctrl_down() { return _ctrlDown; }
+    bool get_alt_down() { return _altDown; }
+    bool get_own_insert_delete_active() { return _myOwnInsertDelete; }
 
 private:
     Gdk::Point _get_point(const Gtk::TextIter& textIter);
