@@ -1,7 +1,7 @@
 /*
  * ct_imports.cc
  *
- * Copyright 2009-2021
+ * Copyright 2009-2023
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -28,7 +28,6 @@
 #include "ct_export2html.h"
 #include "ct_logging.h"
 #include <libxml2/libxml/SAX.h>
-#include <fstream>
 
 namespace {
 
@@ -124,7 +123,7 @@ xmlpp::Element *image_to_xml(xmlpp::Element *parent, const std::string &path, in
     xmlpp::Element* image_element = parent->add_child("encoded_png");
     image_element->set_attribute("char_offset", std::to_string(char_offset));
     image_element->set_attribute(CtConst::TAG_JUSTIFICATION, justification);
-    image_element->set_attribute("link", std::string(CtConst::LINK_TYPE_WEBS) + " " + path);
+    image_element->set_attribute("link", CtConst::LINK_TYPE_WEBS + CtConst::CHAR_SPACE + path);
     image_element->add_child_text(encodedBlob);
 
     if (status_bar) status_bar->update_status("");
@@ -236,7 +235,6 @@ std::unique_ptr<CtImportedNode> CtImports::traverse_dir(const fs::path& dir, CtI
     join_subdir_subnote(dir_node);
     join_parent_dir_subnote(dir_node);
 
-
     return dir_node;
 }
 
@@ -250,7 +248,7 @@ std::unique_ptr<CtImportedNode> CtHtmlImport::import_file(const fs::path& file)
         return nullptr;
     }
     std::string htmlStr = Glib::file_get_contents(file.string());
-    auto node = std::make_unique<CtImportedNode>(file, file.stem().string());
+    auto node = std::make_unique<CtImportedNode>(file, file.stem());
     CtHtml2Xml html2xml{_config};
     html2xml.set_local_dir(file.parent_path().string());
     html2xml.set_outter_xml_doc(node->xml_content.get());
@@ -265,14 +263,22 @@ CtTomboyImport::CtTomboyImport(CtConfig* config) : _config{config}
 std::unique_ptr<CtImportedNode> CtTomboyImport::import_file(const fs::path& file)
 {
     xmlpp::DomParser tomboy_doc;
-    try { tomboy_doc.parse_file(file.string());}
+    try {
+        tomboy_doc.parse_file(file.string());
+    }
     catch (std::exception& ex) {
-        spdlog::error("CtTomboyImport: cannot parse xml file ({}): {}", ex.what(), file);
+        spdlog::error("{}: cannot parse xml file ({}): {}", __FUNCTION__, ex.what(), file.string());
         return nullptr;
     }
 
     // find note
-    xmlpp::Node* note_el = tomboy_doc.get_document()->get_root_node()->get_first_child("note");
+    xmlpp::Node* note_el = tomboy_doc.get_document()->get_root_node();
+    if (note_el->get_name() != "note") {
+        note_el->get_first_child("note");
+        if (not note_el) {
+            return nullptr;
+        }
+    }
 
     // find note name
     Glib::ustring node_name = "???";
@@ -286,101 +292,115 @@ std::unique_ptr<CtImportedNode> CtTomboyImport::import_file(const fs::path& file
 
     // find note's parent
     Glib::ustring parent_name;
-    if (xmlpp::Node* tags_el = note_el->get_first_child("tags"))
+    if (xmlpp::Node* tags_el = note_el->get_first_child("tags")) {
         if (xmlpp::Node* tag_el = tags_el->get_first_child("tag")) {
             Glib::ustring tag_name = dynamic_cast<xmlpp::Element*>(tag_el)->get_child_text()->get_content();
             if (tag_name.size() > 16 && str::startswith(tag_name, "system:notebook:"))
                 parent_name = tag_name.substr(16);
         }
-    if (parent_name.empty())
-        parent_name = "ORPHANS";
+    }
 
     // parse note's content
-    if (xmlpp::Node* text_el = note_el->get_first_child("text"))
-        if (xmlpp::Node* content_el = text_el->get_first_child("note-content"))
-        {
-            auto parent_node = std::make_unique<CtImportedNode>(file, parent_name);
-            auto node = std::make_unique<CtImportedNode>(file, node_name);
+    if (xmlpp::Node* text_el = note_el->get_first_child("text")) {
+        if (xmlpp::Node* content_el = text_el->get_first_child("note-content")) {
+            
+            auto thisNode = std::make_unique<CtImportedNode>(file, node_name);
 
-            _current_node = node->xml_content->create_root_node("root")->add_child("slot");
+            _current_node = thisNode->xml_content->create_root_node("root")->add_child("slot");
             _curr_attributes.clear();
             _chars_counter = 0;
             _is_list_item = false;
             _is_link_to_node = false;
-            _iterate_tomboy_note(dynamic_cast<xmlpp::Element*>(content_el), node);
+            _iterate_tomboy_note(dynamic_cast<xmlpp::Element*>(content_el), thisNode);
 
-            parent_node->children.emplace_back(std::move(node));
-            return parent_node;
+            if (not parent_name.empty()) {
+                auto parent_node = std::make_unique<CtImportedNode>(file, parent_name);
+                parent_node->children.emplace_back(std::move(thisNode));
+                return parent_node;
+            }
+            return thisNode;
         }
+    }
     return nullptr;
 }
 
 void CtTomboyImport::_iterate_tomboy_note(xmlpp::Element* iter, std::unique_ptr<CtImportedNode>& node)
 {
-    for (auto dom_iter: iter->get_children())
-    {
-        auto dom_iter_el = dynamic_cast<xmlpp::Element*>(dom_iter);
-        if (dom_iter->get_name() == "#text")
-        {
-            Glib::ustring text_data = dynamic_cast<xmlpp::TextNode*>(dom_iter)->get_content();
-            if (_curr_attributes[CtConst::TAG_LINK] == "webs ")
-                _curr_attributes[CtConst::TAG_LINK] += text_data;
-            else if (_is_list_item)
-                text_data = _config->charsListbul[0] + CtConst::CHAR_SPACE + text_data;
-
-            xmlpp::Element* el = _rich_text_serialize(text_data);
-             if (_is_link_to_node)
-                node->add_broken_link(text_data, el);
-
-            _chars_counter += text_data.size();
+    for (auto dom_iter : iter->get_children()) {
+        if (auto dom_iter_el = dynamic_cast<xmlpp::Element*>(dom_iter)) {
+            if (dom_iter->get_name() == "bold") {
+                _curr_attributes[CtConst::TAG_WEIGHT] = CtConst::TAG_PROP_VAL_HEAVY;
+                _iterate_tomboy_note(dom_iter_el, node);
+                _curr_attributes[CtConst::TAG_WEIGHT] = "";
+            }
+            else if (dom_iter->get_name() == CtConst::TAG_PROP_VAL_ITALIC) {
+                _curr_attributes[CtConst::TAG_STYLE] = CtConst::TAG_PROP_VAL_ITALIC;
+                _iterate_tomboy_note(dom_iter_el, node);
+                _curr_attributes[CtConst::TAG_STYLE] = "";
+            }
+            else if (dom_iter->get_name() == CtConst::TAG_STRIKETHROUGH) {
+                _curr_attributes[CtConst::TAG_STRIKETHROUGH] = CtConst::TAG_PROP_VAL_TRUE;
+                _iterate_tomboy_note(dom_iter_el, node);
+                _curr_attributes[CtConst::TAG_STRIKETHROUGH] = "";
+            }
+            else if (dom_iter->get_name() == "highlight") {
+                _curr_attributes[CtConst::TAG_BACKGROUND] = CtConst::COLOR_48_YELLOW;
+                _iterate_tomboy_note(dom_iter_el, node);
+                _curr_attributes[CtConst::TAG_BACKGROUND] = "";
+            }
+            else if (dom_iter->get_name() == CtConst::TAG_PROP_VAL_MONOSPACE) {
+                _curr_attributes[CtConst::TAG_FAMILY] = dom_iter->get_name();
+                _iterate_tomboy_note(dom_iter_el, node);
+                _curr_attributes[CtConst::TAG_FAMILY] = "";
+            }
+            else if (dom_iter->get_name() == "size:small") {
+                _curr_attributes[CtConst::TAG_SCALE] = CtConst::TAG_PROP_VAL_SMALL;
+                _iterate_tomboy_note(dom_iter_el, node);
+                _curr_attributes[CtConst::TAG_SCALE] = "";
+            }
+            else if (dom_iter->get_name() == "size:large") {
+                _curr_attributes[CtConst::TAG_SCALE] = CtConst::TAG_PROP_VAL_H2;
+                _iterate_tomboy_note(dom_iter_el, node);
+                _curr_attributes[CtConst::TAG_SCALE] = "";
+            }
+            else if (dom_iter->get_name() == "size:huge") {
+                _curr_attributes[CtConst::TAG_SCALE] = CtConst::TAG_PROP_VAL_H1;
+                _iterate_tomboy_note(dom_iter_el, node);
+                _curr_attributes[CtConst::TAG_SCALE] = "";
+            }
+            else if (dom_iter->get_name() == "link:url") {
+                _curr_attributes[CtConst::TAG_LINK] = "webs ";
+                _iterate_tomboy_note(dom_iter_el, node);
+                _curr_attributes[CtConst::TAG_LINK] = "";
+            }
+            else if (dom_iter->get_name() == "list-item") {
+                _is_list_item = true;
+                _iterate_tomboy_note(dom_iter_el, node);
+                _is_list_item = false;
+            }
+            else if (dom_iter->get_name() == "link:internal") {
+                _is_link_to_node = true;
+                _iterate_tomboy_note(dom_iter_el, node);
+                _is_link_to_node = false;
+            }
+            else {
+                spdlog::debug(dom_iter->get_name());
+                _iterate_tomboy_note(dom_iter_el, node);
+            }
         }
-        else if (dom_iter->get_name() == "bold") {
-            _curr_attributes[CtConst::TAG_WEIGHT] = CtConst::TAG_PROP_VAL_HEAVY;
-            _iterate_tomboy_note(dom_iter_el, node);
-            _curr_attributes[CtConst::TAG_WEIGHT] = "";
-        } else if (dom_iter->get_name() == CtConst::TAG_PROP_VAL_ITALIC) {
-            _curr_attributes[CtConst::TAG_STYLE] = CtConst::TAG_PROP_VAL_ITALIC;
-            _iterate_tomboy_note(dom_iter_el, node);
-            _curr_attributes[CtConst::TAG_STYLE] = "";
-        } else if (dom_iter->get_name() == CtConst::TAG_STRIKETHROUGH) {
-            _curr_attributes[CtConst::TAG_STRIKETHROUGH] = CtConst::TAG_PROP_VAL_TRUE;
-            _iterate_tomboy_note(dom_iter_el, node);
-            _curr_attributes[CtConst::TAG_STRIKETHROUGH] = "";
-        } else if (dom_iter->get_name() == "highlight") {
-            _curr_attributes[CtConst::TAG_BACKGROUND] = CtConst::COLOR_48_YELLOW;
-            _iterate_tomboy_note(dom_iter_el, node);
-            _curr_attributes[CtConst::TAG_BACKGROUND] = "";
-        } else if (dom_iter->get_name() == CtConst::TAG_PROP_VAL_MONOSPACE) {
-            _curr_attributes[CtConst::TAG_FAMILY] = dom_iter->get_name();
-            _iterate_tomboy_note(dom_iter_el, node);
-            _curr_attributes[CtConst::TAG_FAMILY] = "";
-        } else if (dom_iter->get_name() == "size:small") {
-            _curr_attributes[CtConst::TAG_SCALE] = CtConst::TAG_PROP_VAL_SMALL;
-            _iterate_tomboy_note(dom_iter_el, node);
-            _curr_attributes[CtConst::TAG_SCALE] = "";
-        } else if (dom_iter->get_name() == "size:large") {
-            _curr_attributes[CtConst::TAG_SCALE] = CtConst::TAG_PROP_VAL_H2;
-            _iterate_tomboy_note(dom_iter_el, node);
-            _curr_attributes[CtConst::TAG_SCALE] = "";
-        } else if (dom_iter->get_name() == "size:huge") {
-            _curr_attributes[CtConst::TAG_SCALE] = CtConst::TAG_PROP_VAL_H1;
-            _iterate_tomboy_note(dom_iter_el, node);
-            _curr_attributes[CtConst::TAG_SCALE] = "";
-        } else if (dom_iter->get_name() == "link:url") {
-            _curr_attributes[CtConst::TAG_LINK] = "webs ";
-            _iterate_tomboy_note(dom_iter_el, node);
-            _curr_attributes[CtConst::TAG_LINK] = "";
-        } else if (dom_iter->get_name() == "list-item") {
-            _is_list_item = true;
-            _iterate_tomboy_note(dom_iter_el, node);
-            _is_list_item = false;
-        } else if (dom_iter->get_name() == "link:internal") {
-            _is_link_to_node = true;
-            _iterate_tomboy_note(dom_iter_el, node);
-            _is_link_to_node = false;
-        } else {
-            spdlog::debug(dom_iter->get_name());
-            _iterate_tomboy_note(dom_iter_el, node);
+        else {
+            Glib::ustring text_data = dynamic_cast<xmlpp::TextNode*>(dom_iter)->get_content();
+            if (_curr_attributes[CtConst::TAG_LINK] == "webs ") {
+                _curr_attributes[CtConst::TAG_LINK] += text_data;
+            }
+            else if (_is_list_item) {
+                text_data = _config->charsListbul[0] + CtConst::CHAR_SPACE + text_data;
+            }
+            xmlpp::Element* el = _rich_text_serialize(text_data);
+            if (_is_link_to_node) {
+                node->add_broken_link(text_data, el);
+            }
+            _chars_counter += text_data.size();
         }
     }
 }
@@ -401,16 +421,12 @@ std::unique_ptr<CtImportedNode> CtZimImport::import_file(const fs::path& file)
 {
     if (file.extension() != ".txt") return nullptr;
 
-    _ensure_notebook_file_in_dir(file.parent_path());
+    std::unique_ptr<CtImportedNode> node = std::make_unique<CtImportedNode>(file, file.stem());
 
-    std::unique_ptr<CtImportedNode> node = std::make_unique<CtImportedNode>(file, file.stem().string());
-
-    std::ifstream stream;
-    stream.exceptions(std::ios::failbit);
-    stream.open(file.string());
+    const std::string file_contents = Glib::file_get_contents(file.string());
 
     _zim_parser->wipe_doc();
-    _zim_parser->feed(stream);
+    _zim_parser->feed(file_contents);
 
     node->xml_content = _zim_parser->doc().document();
     node->content_broken_links = _zim_parser->doc().broken_links();
@@ -420,21 +436,6 @@ std::unique_ptr<CtImportedNode> CtZimImport::import_file(const fs::path& file)
 
 CtZimImport::~CtZimImport() = default;
 
-void CtZimImport::_ensure_notebook_file_in_dir(const fs::path& dir)
-{
-    if (_has_notebook_file) return;
-    for (auto dir_item: fs::get_dir_entries(dir))
-        if (dir_item.filename() == "notebook.zim")
-        {
-            _has_notebook_file = true;
-            break;
-        }
-
-    if (!_has_notebook_file) {
-        throw CtImportException(fmt::format("Directory: {} does not contain a notebook.zim file", dir));
-    }
-}
-
 CtMDImport::~CtMDImport() = default;
 
 std::unique_ptr<CtImportedNode> CtPlainTextImport::import_file(const fs::path& file)
@@ -445,7 +446,7 @@ std::unique_ptr<CtImportedNode> CtPlainTextImport::import_file(const fs::path& f
     try {
         std::string converted = Glib::file_get_contents(file.string());
         CtStrUtil::convert_if_not_utf8(converted, true/*sanitise*/);
-        auto node = std::make_unique<CtImportedNode>(file, file.stem().string());
+        auto node = std::make_unique<CtImportedNode>(file, file.stem());
         node->xml_content->create_root_node("root")->add_child("slot")->add_child("rich_text")->add_child_text(converted);
         node->node_syntax = CtConst::PLAIN_TEXT_ID;
         return node;
@@ -465,35 +466,16 @@ std::unique_ptr<CtImportedNode> CtMDImport::import_file(const fs::path& file)
     if (file.extension() != ".md")
         return nullptr;
 
-    std::ifstream infile(file.string());
-    if (!infile) throw std::runtime_error(fmt::format("CtMDImport: cannot open file, what: {}, file: {}", strerror(errno), file));
+    const std::string file_contents = Glib::file_get_contents(file.string());
     _parser->wipe_doc();
-    _parser->feed(infile);
+    _parser->feed(file_contents);
 
-    std::unique_ptr<CtImportedNode> node = std::make_unique<CtImportedNode>(file, file.stem().string());
+    std::unique_ptr<CtImportedNode> node = std::make_unique<CtImportedNode>(file, file.stem());
     node->xml_content = _parser->doc().document();
 
     return node;
 }
 
-CtPandocImport::CtPandocImport(CtConfig* config): _config(config)
-{
-}
-
-std::unique_ptr<CtImportedNode> CtPandocImport::import_file(const fs::path& file)
-{
-    std::stringstream html_buff;
-    CtPandoc::to_html(file, html_buff);
-
-    std::unique_ptr<CtImportedNode> node = std::make_unique<CtImportedNode>(file, file.stem().string());
-
-    CtHtml2Xml parser(_config);
-    parser.set_outter_xml_doc(node->xml_content.get());
-    parser.feed(html_buff.str());
-
-    return node;
-}
-
 std::unique_ptr<CtImportedNode> CtKeepnoteImport::import_file(const fs::path& file)
 {
     for (auto ignore: {"__TRASH__", "__NOTEBOOK__"})
@@ -506,7 +488,7 @@ std::unique_ptr<CtImportedNode> CtKeepnoteImport::import_file(const fs::path& fi
     CtHtml2Xml parser{_config};
     parser.set_local_dir(file.parent_path().string());
     parser.feed(keepnoteStr);
-    auto node = std::make_unique<CtImportedNode>(file, file.parent_path().stem().string());
+    auto node = std::make_unique<CtImportedNode>(file, file.parent_path().stem());
     node->xml_content->create_root_node_by_import(parser.doc().get_root_node());
     //spdlog::debug(keepnoteStr);
     //spdlog::debug(node->xml_content->write_to_string());
@@ -537,8 +519,8 @@ ITER up_to_same_level(ITER start, ITER upper_bound, int level)
 }
 
 std::unique_ptr<CtImportedNode> mempad_pages_to_nodes(const CtMempadParser::page& page,
-                                                        const std::vector<CtMempadParser::page>& child_pages,
-                                                        const fs::path& path)
+                                                      const std::vector<CtMempadParser::page>& child_pages,
+                                                      const fs::path& path)
 {
     auto node = mempad_page_to_node(page, path);
     for (auto iter = child_pages.begin(); iter != child_pages.end(); ++iter) {
@@ -555,7 +537,8 @@ std::unique_ptr<CtImportedNode> mempad_pages_to_nodes(const CtMempadParser::page
     return node;
 }
 
-std::unique_ptr<CtImportedNode> mempad_tree_to_node(const std::vector<CtMempadParser::page>& pages, const fs::path& path)
+std::unique_ptr<CtImportedNode> mempad_tree_to_node(const std::vector<CtMempadParser::page>& pages,
+                                                    const fs::path& path)
 {
     CtMempadParser::page dummy_page{
         .level = 0,
@@ -563,7 +546,6 @@ std::unique_ptr<CtImportedNode> mempad_tree_to_node(const std::vector<CtMempadPa
         .contents = ""
     };
     auto node = mempad_pages_to_nodes(dummy_page, pages, path);
-
     return node;
 }
 
@@ -571,37 +553,38 @@ std::unique_ptr<CtImportedNode> mempad_tree_to_node(const std::vector<CtMempadPa
 
 std::unique_ptr<CtImportedNode> CtMempadImporter::import_file(const fs::path& file)
 {
-    std::ifstream infile{file.string()};
-
+    const std::string file_contents = Glib::file_get_contents(file.string());
     CtMempadParser parser;
-
-    parser.feed(infile);
-
+    parser.feed(file_contents);
     std::vector<CtMempadParser::page> pages = parser.parsed_pages();
-
     auto node = mempad_tree_to_node(pages, file);
+    return node;
+}
 
+std::unique_ptr<CtImportedNode> CtIndentedListImporter::import_file(const fs::path& file)
+{
+    const std::string file_contents = Glib::file_get_contents(file.string());
+    CtIndentedListParser parser;
+    parser.feed(file_contents);
+    std::vector<CtMempadParser::page> pages = parser.parsed_pages();
+    auto node = mempad_tree_to_node(pages, file);
     return node;
 }
 
 std::unique_ptr<CtImportedNode> CtTreepadImporter::import_file(const fs::path& file)
 {
-    std::ifstream infile{file.string()};
-
+    const std::string file_contents = Glib::file_get_contents(file.string());
     CtTreepadParser parser;
-
-    parser.feed(infile);
-
+    parser.feed(file_contents);
     std::vector<CtMempadParser::page> pages = parser.parsed_pages();
-
     auto node = mempad_tree_to_node(pages, file);
-
     return node;
 }
 
 namespace {
 
-std::unique_ptr<CtImportedNode> to_ct_node(const CtLeoParser::leo_node& leo_node, const fs::path& path) {
+std::unique_ptr<CtImportedNode> to_ct_node(const CtLeoParser::leo_node& leo_node, const fs::path& path)
+{
     auto node = std::make_unique<CtImportedNode>(path, leo_node.name);
     node->xml_content = std::make_shared<xmlpp::Document>();
     create_root_plaintext_text_el(*node->xml_content, leo_node.content);
@@ -637,7 +620,7 @@ std::unique_ptr<CtImportedNode> node_to_ct_node(const CtRedNotebookParser::node&
 
 std::unique_ptr<CtImportedNode> generate_ct_node_hierarchy(std::string&& root_name, const std::vector<CtRedNotebookParser::node>& nodes, const fs::path& path)
 {
-    CtRedNotebookParser::node root { std::move(root_name) };
+    CtRedNotebookParser::node root{ std::move(root_name) };
     auto ct_root = node_to_ct_node(root, path);
 
     for (const auto& node : nodes) {
@@ -650,45 +633,29 @@ std::unique_ptr<CtImportedNode> generate_ct_node_hierarchy(std::string&& root_na
 
 std::unique_ptr<CtImportedNode> CtLeoImporter::import_file(const fs::path& path)
 {
-    std::ifstream in{path.string()};
-    if (!in) {
-        throw std::runtime_error(fmt::format("Failed to initalise input file, path: <{}>", path));
-    }
-
+    const std::string file_contents = Glib::file_get_contents(path.string());
     CtLeoParser parser;
-    parser.feed(in);
-
+    parser.feed(file_contents);
     return generate_leo_root_node(parser.nodes(), path);
 }
 
 std::unique_ptr<CtImportedNode> CtRedNotebookImporter::import_file(const fs::path& path)
 {
-    std::ifstream in{path.string()};
-    if (!in) {
-        throw std::runtime_error("Failed to initalise import file");
-    }
-
-    return _parse_input(in, path);
+    return _parse_input(path);
 }
 
-std::unique_ptr<CtImportedNode> CtRedNotebookImporter::_parse_input(std::ifstream& infile, const fs::path& path)
+std::unique_ptr<CtImportedNode> CtRedNotebookImporter::_parse_input(const fs::path& path)
 {
-    CtRedNotebookParser p{_ct_config};
-
-    p.feed(infile);
-    const auto& nodes = p.nodes();
-
-    return generate_ct_node_hierarchy("RedNotebook Root", nodes, path);
+    const std::string file_contents = Glib::file_get_contents(path.string());
+    CtRedNotebookParser parser{_ct_config};
+    parser.feed(file_contents);
+    return generate_ct_node_hierarchy("RedNotebook Root", parser.nodes(), path);
 }
 
 std::unique_ptr<CtImportedNode> CtNoteCaseHTMLImporter::import_file(const fs::path& path)
 {
-    std::ifstream in{path.string()};
-    if (!in) {
-        throw std::runtime_error("Failed to setup input file for reading");
-    }
-
+    const std::string file_contents = Glib::file_get_contents(path.string());
     CtNoteCaseHTMLParser parser{_ct_config};
-    parser.feed(in);
+    parser.feed(file_contents);
     return generate_ct_node_hierarchy("NoteCase Root", parser.nodes(), path);
 }
