@@ -1,7 +1,7 @@
 /*
  * ct_main_win.h
  *
- * Copyright 2009-2022
+ * Copyright 2009-2023
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -67,7 +67,7 @@ struct CtWinHeader
     Gtk::Image       bookmarkIcon;
     Gtk::Image       ghostIcon;
     Gtk::EventBox    eventBox;
-    std::map<Gtk::Button*, gint64> button_to_node_id;
+    std::unordered_map<Gtk::Button*, gint64> button_to_node_id;
 };
 
 class CtConfig;
@@ -101,8 +101,8 @@ public:
 
     bool file_open(const fs::path& filepath, const std::string& node_to_focus, const std::string& anchor_to_focus, const Glib::ustring password = "");
     bool file_save_ask_user();
-    void file_save(bool need_vacuum);
-    void file_save_as(const std::string& new_filepath, const Glib::ustring& password);
+    bool file_save(const bool need_vacuum);
+    void file_save_as(const std::string& new_filepath, const CtDocType doc_type, const Glib::ustring& password);
     void file_autosave_restart();
     void mod_time_sentinel_restart();
     bool file_insert_plain_text(const fs::path& filepath);
@@ -194,6 +194,14 @@ public:
     void show_hide_tree_lines(bool visible) { _uCtTreeview->set_enable_tree_lines(visible); }
     void set_toolbars_icon_size(int size)   { for (auto pToolbar: _pToolbars) pToolbar->property_icon_size() = CtMiscUtil::getIconSize(size); }
     void show_hide_tree_view(bool visible)  { _scrolledwindowTree.property_visible() = visible; }
+
+    Gtk::Widget* get_vte()        { return _pVte; }
+    bool         is_vte_visible() { return _hBoxVte.property_visible(); }
+    bool         show_hide_vte_cmd_passed_as_first_in_session(bool visible, const char* first_cmd_passed); // return true if the command was passed as first in the session
+    void         exec_in_vte(const std::string& shell_cmd);
+    void         update_vte_settings();
+    void         restart_vte(const char* first_cmd_passed);
+
     void show_hide_win_header(bool visible) { _ctWinHeader.headerBox.property_visible() = visible; }
 
     void resetPrevTreeIter()                { _prevTreeIter = CtTreeIter(); }
@@ -206,6 +214,7 @@ public:
     bool start_on_systray_delayed_file_open_kick();
     void set_systray_can_hide(const bool systrayCanHide) { _systrayCanHide = systrayCanHide; }
     bool get_systray_can_hide() const { return _systrayCanHide; }
+    void toggle_always_on_top() { _alwaysOnTop = not _alwaysOnTop; set_keep_above(_alwaysOnTop); }
 
 private:
     bool _on_window_key_press_event(GdkEventKey* event);
@@ -251,6 +260,8 @@ private:
     const bool                   _no_gui;
     CtConfig*                    _pCtConfig;
     CtTmp*                       _pCtTmp;
+    Gtk::Widget*                 _pVte{nullptr};
+    GPid                         _vtePid{0};
     Gtk::IconTheme*              _pGtkIconTheme;
     Glib::RefPtr<Gtk::TextTagTable> _rGtkTextTagTable;
     Glib::RefPtr<Gtk::CssProvider>  _rGtkCssProvider;
@@ -265,7 +276,9 @@ private:
 
     Gtk::VBox                    _vboxMain;
     Gtk::VBox                    _vboxText;
+    Gtk::HBox                    _hBoxVte;
     Gtk::HPaned                  _hPaned;
+    Gtk::VPaned                  _vPaned;
     Gtk::HeaderBar*              _pHeaderBar{nullptr};
     Gtk::MenuBar*                _pMenuBar{nullptr};
     Gtk::ScrolledWindow*         _pScrolledWindowMenuBar{nullptr};
@@ -305,6 +318,7 @@ private:
     std::string         _startOnSystray_delayedNodeName;
     std::string         _startOnSystray_delayedAnchorName;
     bool                _systrayCanHide{true};
+    bool                _alwaysOnTop{false};
 
 public:
     sigc::signal<void>             signal_app_new_instance = sigc::signal<void>();
@@ -316,4 +330,11 @@ public:
 
     sigc::signal<void, CtMainWin*> signal_app_quit_or_hide_window = sigc::signal<void, CtMainWin*>();
     sigc::signal<void, CtMainWin*> signal_app_quit_window = sigc::signal<void, CtMainWin*>();
+
+public:
+    Glib::Dispatcher dispatcherErrorMsg;
+    ThreadSafeDEQueue<std::string, 2> errorsDEQueue;
+
+private:
+    void _on_dispatcher_error_msg();
 };
