@@ -1,7 +1,7 @@
 /*
  * ct_main_win_events.cc
  *
- * Copyright 2009-2021
+ * Copyright 2009-2023
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -86,7 +86,7 @@ bool CtMainWin::_on_window_key_press_event(GdkEventKey* event)
 {
     if (event->state & GDK_CONTROL_MASK) {
         if (event->keyval == GDK_KEY_Tab) {
-            _uCtActions->toggle_tree_text();
+            _uCtActions->toggle_focus_tree_text();
             return true;
         }
     }
@@ -255,7 +255,7 @@ bool CtMainWin::_on_treeview_key_press_event(GdkEventKey* event)
             return true;
         }
         else if (event->keyval == GDK_KEY_Tab) {
-            _uCtActions->toggle_tree_text();
+            _uCtActions->toggle_focus_tree_text();
             return true;
         }
         else if (event->keyval == GDK_KEY_Delete) {
@@ -382,6 +382,7 @@ bool CtMainWin::_on_window_configure_event(GdkEventConfigure*/*configure_event*/
 void CtMainWin::_on_textview_size_allocate(Gtk::Allocation& allocation)
 {
     _pCtConfig->hpanedPos = _hPaned.property_position();
+    _pCtConfig->vpanedPos = _vPaned.property_position();
     if (_prevTextviewWidth == 0) {
         _prevTextviewWidth = allocation.get_width();
     }
@@ -407,26 +408,13 @@ bool CtMainWin::_on_textview_event(GdkEvent* event)
     if (event->key.state & Gdk::SHIFT_MASK) {
         if (event->key.keyval == GDK_KEY_ISO_Left_Tab and !curr_buffer->get_has_selection()) {
             auto iter_insert = curr_buffer->get_insert()->get_iter();
-            CtListInfo list_info = CtList(this, curr_buffer).get_paragraph_list_info(iter_insert);
+            CtListInfo list_info = CtList{_pCtConfig, curr_buffer}.get_paragraph_list_info(iter_insert);
             if (list_info and list_info.level) {
                 _ctTextview.list_change_level(iter_insert, list_info, false);
                 return true;
             }
         }
     }
-    else if (event->key.state & Gdk::CONTROL_MASK and event->key.keyval == GDK_KEY_space) {
-        if (_try_move_focus_to_anchored_widget_if_on_it()) {
-            return true;
-        }
-        auto iter_insert = _ctTextview.get_buffer()->get_insert()->get_iter();
-        CtListInfo list_info = CtList(this, curr_buffer).get_paragraph_list_info(iter_insert);
-        if (list_info and list_info.type == CtListType::Todo)
-            if (_uCtActions->_is_curr_node_not_read_only_or_error()) {
-                auto iter_start_list = curr_buffer->get_iter_at_offset(list_info.startoffs + 3*list_info.level);
-                CtList(this, curr_buffer).todo_list_rotate_status(iter_start_list);
-                return true;
-            }
-    }
     else if (GDK_KEY_Return == event->key.keyval or GDK_KEY_KP_Enter == event->key.keyval) {
         auto iter_insert = curr_buffer->get_insert()->get_iter();
         if (iter_insert)
@@ -461,7 +449,7 @@ bool CtMainWin::_on_textview_event(GdkEvent* event)
     else if (event->key.keyval == GDK_KEY_Tab) {
         if (not curr_buffer->get_has_selection()) {
             auto iter_insert = curr_buffer->get_insert()->get_iter();
-            CtListInfo list_info = CtList(this, curr_buffer).get_paragraph_list_info(iter_insert);
+            CtListInfo list_info = CtList{_pCtConfig, curr_buffer}.get_paragraph_list_info(iter_insert);
             if (list_info) {
                 _ctTextview.list_change_level(iter_insert, list_info, true);
                 return true;
@@ -478,7 +466,7 @@ bool CtMainWin::_on_textview_event(GdkEvent* event)
             if (widgets.empty()) {
                 return false;
             }
-            if (dynamic_cast<CtTable*>(widgets.front())) {
+            if (dynamic_cast<CtTableCommon*>(widgets.front())) {
                 curr_buffer->place_cursor(iter_sel_end);
                 _ctTextview.grab_focus();
                 return true;
@@ -487,13 +475,29 @@ bool CtMainWin::_on_textview_event(GdkEvent* event)
         }
     }
     else if (event->key.state & Gdk::CONTROL_MASK) {
-        if (event->key.keyval == GDK_KEY_plus || event->key.keyval == GDK_KEY_KP_Add || event->key.keyval == GDK_KEY_equal) {
-            _ctTextview.zoom_text(true, curr_tree_iter().get_node_syntax_highlighting());
-            return true;
-        }
-        else if (event->key.keyval == GDK_KEY_minus|| event->key.keyval == GDK_KEY_KP_Subtract) {
-            _ctTextview.zoom_text(false, curr_tree_iter().get_node_syntax_highlighting());
-            return true;
+        if (not (event->key.state & Gdk::MOD1_MASK)) {
+            if (event->key.keyval == GDK_KEY_space) {
+                if (_try_move_focus_to_anchored_widget_if_on_it()) {
+                    return true;
+                }
+                auto iter_insert = _ctTextview.get_buffer()->get_insert()->get_iter();
+                CtListInfo list_info = CtList{_pCtConfig, curr_buffer}.get_paragraph_list_info(iter_insert);
+                if (list_info and list_info.type == CtListType::Todo) {
+                    if (_uCtActions->_is_curr_node_not_read_only_or_error()) {
+                        auto iter_start_list = curr_buffer->get_iter_at_offset(list_info.startoffs + 3*list_info.level);
+                        CtList{_pCtConfig, curr_buffer}.todo_list_rotate_status(iter_start_list);
+                        return true;
+                    }
+                }
+            }
+            if (event->key.keyval == GDK_KEY_plus || event->key.keyval == GDK_KEY_KP_Add || event->key.keyval == GDK_KEY_equal) {
+                _ctTextview.zoom_text(true, curr_tree_iter().get_node_syntax_highlighting());
+                return true;
+            }
+            else if (event->key.keyval == GDK_KEY_minus|| event->key.keyval == GDK_KEY_KP_Subtract) {
+                _ctTextview.zoom_text(false, curr_tree_iter().get_node_syntax_highlighting());
+                return true;
+            }
         }
     }
     return false;
