@@ -131,25 +131,19 @@ std::string CtMiscUtil::get_ct_language()
 std::string CtMiscUtil::get_doc_extension(const CtDocType ctDocType, const CtDocEncrypt ctDocEncrypt)
 {
     std::string ret_val;
-    if (CtDocType::XML == ctDocType)
-    {
-        if (CtDocEncrypt::False == ctDocEncrypt)
-        {
+    if (CtDocType::XML == ctDocType) {
+        if (CtDocEncrypt::False == ctDocEncrypt) {
             ret_val = CtConst::CTDOC_XML_NOENC;
         }
-        else if (CtDocEncrypt::True == ctDocEncrypt)
-        {
+        else if (CtDocEncrypt::True == ctDocEncrypt) {
             ret_val = CtConst::CTDOC_XML_ENC;
         }
     }
-    else if (CtDocType::SQLite == ctDocType)
-    {
-        if (CtDocEncrypt::False == ctDocEncrypt)
-        {
+    else if (CtDocType::SQLite == ctDocType) {
+        if (CtDocEncrypt::False == ctDocEncrypt) {
             ret_val = CtConst::CTDOC_SQLITE_NOENC;
         }
-        else if (CtDocEncrypt::True == ctDocEncrypt)
-        {
+        else if (CtDocEncrypt::True == ctDocEncrypt) {
             ret_val = CtConst::CTDOC_SQLITE_ENC;
         }
     }
@@ -159,9 +153,17 @@ std::string CtMiscUtil::get_doc_extension(const CtDocType ctDocType, const CtDoc
 void CtMiscUtil::filepath_extension_fix(const CtDocType ctDocType, const CtDocEncrypt ctDocEncrypt, std::string& filepath)
 {
     const std::string docExt{get_doc_extension(ctDocType, ctDocEncrypt)};
-    if (false == Glib::str_has_suffix(filepath, docExt))
-    {
-        filepath += docExt;
+    if (docExt.empty() or not Glib::str_has_suffix(filepath, docExt)) {
+        if (Glib::str_has_suffix(filepath, CtConst::CTDOC_XML_NOENC) or
+            Glib::str_has_suffix(filepath, CtConst::CTDOC_XML_ENC) or
+            Glib::str_has_suffix(filepath, CtConst::CTDOC_SQLITE_NOENC) or
+            Glib::str_has_suffix(filepath, CtConst::CTDOC_SQLITE_ENC))
+        {
+            filepath = filepath.substr(0, filepath.length()-4);
+        }
+        if (not docExt.empty()) {
+            filepath += docExt;
+        }
     }
 }
 
@@ -402,7 +404,7 @@ void CtTextIterUtil::generic_process_slot(const CtConfig* const pCtConfig,
                                           const int start_offset,
                                           const int end_offset,
                                           const Glib::RefPtr<Gtk::TextBuffer>& rTextBuffer,
-                                          SerializeFunc serialize_func,
+                                          SerializeFunc f_serialize_func,
                                           const bool list_info/*= false*/)
 {
     CtCurrAttributesMap curr_attributes;
@@ -420,8 +422,7 @@ void CtTextIterUtil::generic_process_slot(const CtConfig* const pCtConfig,
         }
     }
 
-    CtListInfo curr_list_info, prev_list_info;
-    bool list_info_changed{false};
+    CtListInfo curr_list_info;
     bool last_was_newline{false};
     if (not curr_end_iter.backward_char()) {
         last_was_newline = true;
@@ -438,29 +439,21 @@ void CtTextIterUtil::generic_process_slot(const CtConfig* const pCtConfig,
 
         if (list_info and last_was_newline) {
             curr_list_info = CtList{pCtConfig, rTextBuffer}.get_paragraph_list_info(curr_end_iter);
-            if (curr_list_info != prev_list_info) {
-                list_info_changed = true;
-                prev_list_info = curr_list_info;
-            }
         }
 
         last_was_newline = '\n' == curr_end_iter.get_char();
 
         if (CtTextIterUtil::rich_text_attributes_update(curr_end_iter, curr_attributes, delta_attributes) or
-            (list_info and last_was_newline and list_info_changed))
+            (list_info and last_was_newline))
         {
-            serialize_func(curr_start_iter, curr_end_iter, curr_attributes, &curr_list_info);
-
-            for (auto& currDelta : delta_attributes) {
-                curr_attributes[currDelta.first] = currDelta.second;
-            }
+            f_serialize_func(curr_start_iter, curr_end_iter, curr_attributes, &curr_list_info);
+            for (auto& currDelta : delta_attributes) curr_attributes[currDelta.first] = currDelta.second;
             curr_start_iter = curr_end_iter;
-            if (list_info_changed) list_info_changed = false;
         }
     }
 
     if (curr_start_iter.compare(real_end_iter) < 0) {
-        serialize_func(curr_start_iter, real_end_iter, curr_attributes, &curr_list_info);
+        f_serialize_func(curr_start_iter, real_end_iter, curr_attributes, &curr_list_info);
     }
 }
 
@@ -586,7 +579,7 @@ int CtStrUtil::gtk_pango_find_start_of_dir(const gchar* text, const PangoDirecti
 std::vector<bool> CtStrUtil::get_rtl_for_lines(const Glib::ustring& text)
 {
     std::vector<bool> ret_vec;
-    std::vector<Glib::ustring> lines = str::split(text, CtConst::CHAR_NEWLINE);
+    std::vector<Glib::ustring> lines = str::split(text, "\n");
     for (const auto& curr_line : lines) {
         ret_vec.push_back(PANGO_DIRECTION_RTL == CtStrUtil::gtk_pango_find_base_dir(curr_line.c_str(), -1));
     }
@@ -829,32 +822,36 @@ void CtStrUtil::convert_if_not_utf8(std::string& inOutText, const bool sanitise)
 
 Glib::ustring CtFontUtil::get_font_family(const Glib::ustring& fontStr)
 {
+    try {
+        std::vector<Glib::ustring> fontStr_splitted = str::split(fontStr, " ");
+        fontStr_splitted.pop_back();
+        Glib::ustring retVal = str::join(fontStr_splitted, CtConst::CHAR_SPACE);
+        return retVal;
+    }
+    catch (...) {
+        spdlog::warn("{} {}", __FUNCTION__, fontStr.raw());
+    }
     return Pango::FontDescription(fontStr).get_family();
 }
 
-int CtFontUtil::get_font_size(const Pango::FontDescription& fontDesc)
-{
-    return fontDesc.get_size()/Pango::SCALE;
-}
-
 int CtFontUtil::get_font_size(const Glib::ustring& fontStr)
 {
-    return get_font_size(Pango::FontDescription(fontStr));
+    try {
+        const std::vector<Glib::ustring> fontStr_splitted = str::split(fontStr, " ");
+        const int retVal = std::stoi(fontStr_splitted.back());
+        return retVal;
+    }
+    catch (...) {
+        spdlog::warn("{} {}", __FUNCTION__, fontStr.raw());
+    }
+    return Pango::FontDescription(fontStr).get_size()/Pango::SCALE;
 }
 
 Glib::ustring CtFontUtil::get_font_str(const Glib::ustring& fontFamily, const int fontSize)
 {
-    return fontFamily + " " + std::to_string(fontSize);
+    return fontFamily + CtConst::CHAR_SPACE + std::to_string(fontSize);
 }
 
-Glib::ustring CtFontUtil::get_font_str(const Pango::FontDescription& fontDesc)
-{
-    Glib::ustring font_family = fontDesc.get_family();
-    auto font_family_splitted = str::split(font_family, ",");
-    return font_family_splitted.back() + " " + std::to_string(get_font_size(fontDesc));
-}
-
-
 void CtRgbUtil::set_rgb24str_from_rgb24int(guint32 rgb24Int, char* rgb24StrOut)
 {
     guint8 r = (rgb24Int >> 16) & 0xff;
