@@ -502,10 +502,42 @@ void CtMempadParser::feed(const std::string& data)
     _parsed_pages.insert(_parsed_pages.cend(), new_pages.begin(), new_pages.end());
 }
 
+void CtIndentedListParser::feed(const std::string& data)
+{
+    std::vector<std::string> list_rows = str::split(str::replace(data, CtConst::CHAR_CR, ""), "\n");
+    int max_lvl{0};
+    for (const auto& row : list_rows) {
+        int page_lvl{1};
+        std::string title{row};
+        while (title.size() and (title.front() == ' ' or title.front() == '\t')) {
+            ++page_lvl;
+            title = title.substr(1);
+        }
+        if (title.size()) {
+            //spdlog::debug("level={} name={}", page_lvl, title);
+            while ((page_lvl - max_lvl) > 1) {
+                _parsed_pages.emplace_back(CtMempadParser::page{
+                    .level = ++max_lvl,
+                    .name = std::string{},
+                    .contents = std::string{}
+                });
+            }
+            if (page_lvl > max_lvl) {
+                max_lvl = page_lvl;
+            }
+            _parsed_pages.emplace_back(CtMempadParser::page{
+                .level = page_lvl,
+                .name = title,
+                .contents = std::string{}
+            });
+        }
+    }
+}
+
 void CtTreepadParser::feed(const std::string& data)
 {
     Glib::RefPtr<Glib::Regex> rRegExpInteger = Glib::Regex::create("\\d+");
-    for (auto& lineStr : str::split(data, CtConst::CHAR_NEWLINE)) {
+    for (auto& lineStr : str::split(data, "\n")) {
         size_t currSize = lineStr.size();
         if (currSize > 0 and lineStr.at(currSize - 1) == '\r') {
             lineStr.erase(currSize - 1);
@@ -554,7 +586,7 @@ void CtZimParser::feed(const std::string& data)
 {
     bool found_header{false};
     try {
-        for (const auto& line : str::split(data, CtConst::CHAR_NEWLINE)) {
+        for (const auto& line : str::split(data, "\n")) {
             if (not found_header) {
                 // Creation-Date: .* is the final line of the header
                 if (line.find("Creation-Date:") != std::string::npos) {
