@@ -1,7 +1,7 @@
 /*
  * ct_state_machine.cc
  *
- * Copyright 2009-2022
+ * Copyright 2009-2023
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -163,24 +163,19 @@ CtAnchoredWidget* CtAnchoredWidgetState_Codebox::to_widget(CtMainWin* pCtMainWin
 }
 
 // Table
-CtAnchoredWidgetState_Table::CtAnchoredWidgetState_Table(CtTable* table)
+CtAnchoredWidgetState_TableCommon::CtAnchoredWidgetState_TableCommon(const CtTableCommon* table)
  : CtAnchoredWidgetState{table->getOffset(), table->getJustification()}
  , colWidthDefault{table->get_col_width_default()}
  , colWidths{table->get_col_widths_raw()}
  , currRow{table->current_row()}
  , currCol{table->current_column()}
 {
-    for (auto& row : table->get_table_matrix()) {
-        rows.push_back(std::vector<Glib::ustring>());
-        for (auto& cell : row) {
-            rows.back().push_back(cell->get_text_content());
-        }
-    }
+    table->write_strings_matrix(rows);
 }
 
-bool CtAnchoredWidgetState_Table::equal(std::shared_ptr<CtAnchoredWidgetState> state)
+bool CtAnchoredWidgetState_TableCommon::equal(std::shared_ptr<CtAnchoredWidgetState> state)
 {
-    CtAnchoredWidgetState_Table* other_state = dynamic_cast<CtAnchoredWidgetState_Table*>(state.get());
+    CtAnchoredWidgetState_TableCommon* other_state = dynamic_cast<CtAnchoredWidgetState_TableCommon*>(state.get());
     return other_state and
            charOffset == other_state->charOffset and
            justification == other_state->justification and
@@ -191,24 +186,46 @@ bool CtAnchoredWidgetState_Table::equal(std::shared_ptr<CtAnchoredWidgetState> s
            rows == other_state->rows;
 }
 
-CtAnchoredWidget* CtAnchoredWidgetState_Table::to_widget(CtMainWin* pCtMainWin)
+CtTableLight* CtAnchoredWidgetState_TableCommon::to_widget_light(CtMainWin* pCtMainWin) const
 {
     CtTableMatrix tableMatrix;
-    for (const auto& row : rows)
-    {
-        tableMatrix.push_back(CtTableRow());
+    tableMatrix.reserve(rows.size());
+    for (const auto& row : rows) {
+        tableMatrix.push_back(CtTableRow{});
+        tableMatrix.back().reserve(row.size());
+        for (const auto& cell : row) {
+            tableMatrix.back().push_back(new Glib::ustring{cell});
+        }
+    }
+    return new CtTableLight{pCtMainWin,
+                            tableMatrix,
+                            colWidthDefault,
+                            charOffset,
+                            justification,
+                            colWidths,
+                            currRow,
+                            currCol};
+}
+
+CtTableHeavy* CtAnchoredWidgetState_TableCommon::to_widget_heavy(CtMainWin* pCtMainWin) const
+{
+    CtTableMatrix tableMatrix;
+    tableMatrix.reserve(rows.size());
+    for (const auto& row : rows) {
+        tableMatrix.push_back(CtTableRow{});
+        tableMatrix.back().reserve(row.size());
         for (const auto& cell : row) {
             tableMatrix.back().push_back(new CtTextCell{pCtMainWin, cell, CtConst::TABLE_CELL_TEXT_ID});
         }
     }
-    return new CtTable{pCtMainWin,
-                       tableMatrix,
-                       colWidthDefault,
-                       charOffset,
-                       justification,
-                       colWidths,
-                       currRow,
-                       currCol};
+    return new CtTableHeavy{pCtMainWin,
+                            tableMatrix,
+                            colWidthDefault,
+                            charOffset,
+                            justification,
+                            colWidths,
+                            currRow,
+                            currCol};
 }
 
 CtStateMachine::CtStateMachine(CtMainWin *pCtMainWin)
@@ -386,7 +403,8 @@ void CtStateMachine::update_state(CtTreeIter tree_iter)
     }
 
     auto new_state = std::shared_ptr<CtNodeState>(new CtNodeState());
-    CtStorageXmlHelper(_pCtMainWin).save_buffer_no_widgets_to_xml(new_state->buffer_xml.get_root_node(), tree_iter.get_node_text_buffer(), 0, -1, 'n');
+    CtStorageXmlHelper(_pCtMainWin).save_buffer_no_widgets_to_xml(new_state->buffer_xml.get_root_node(),
+                                                                  tree_iter.get_node_text_buffer(), 0, -1, 'n');
     new_state->buffer_xml_string = new_state->buffer_xml.write_to_string();
     for (auto widget : tree_iter.get_anchored_widgets()) {
         new_state->widgetStates.push_back(widget->get_state());
