@@ -279,6 +279,17 @@ void CtTextView::for_event_after_button_press(GdkEvent* event)
         // the issue: get_iter_at_position always gives iter, so we have to check if iter is valid
         Gdk::Rectangle iter_rect;
         get_iter_location(text_iter, iter_rect);
+        if (1 == event->button.button) {
+            const auto pGutterLineNumbers = get_gutter(Gtk::TEXT_WINDOW_LEFT);
+            if (pGutterLineNumbers) {
+                const auto pGutterLNWindow = pGutterLineNumbers->get_window();
+                if (pGutterLNWindow and pGutterLNWindow->gobj() == event->button.window) {
+                    // line number click
+                    _pCtMainWin->apply_tag_try_automatic_bounds_triple_click(text_buffer, text_iter);
+                    return;
+                }
+            }
+        }
         //spdlog::debug("x={} recx={} recw={}", x, iter_rect.get_x(), iter_rect.get_width());
         if ( (iter_rect.get_width() >= 0/*LTR*/ and iter_rect.get_x() <= x and x <= (iter_rect.get_x() + iter_rect.get_width())) or
              (iter_rect.get_width() < 0/*RTL*/ and (iter_rect.get_x() + iter_rect.get_width()) <= x and x <= iter_rect.get_x()) )
@@ -626,33 +637,31 @@ void CtTextView::cursor_and_tooltips_reset()
 void CtTextView::zoom_text(const bool is_increase, const std::string& syntaxHighlighting)
 {
     Glib::RefPtr<Gtk::StyleContext> context = get_style_context();
-    Pango::FontDescription fontDesc = context->get_font(context->get_state());
+    const Pango::FontDescription fontDesc = context->get_font(context->get_state());
     int size = fontDesc.get_size() / Pango::SCALE + (is_increase ? 1 : -1);
     if (size < 6) size = 6;
-    fontDesc.set_size(size * Pango::SCALE);
 
     if (syntaxHighlighting == CtConst::RICH_TEXT_ID or syntaxHighlighting == CtConst::TABLE_CELL_TEXT_ID) {
-        _pCtConfig->rtFont = CtFontUtil::get_font_str(fontDesc);
+        _pCtConfig->rtFont = CtFontUtil::get_font_str(CtFontUtil::get_font_family(_pCtConfig->rtFont), size);
         spdlog::debug("rtFont {}", _pCtConfig->rtFont);
         // also fix monospace font size
         if (_pCtConfig->msDedicatedFont and not _pCtConfig->monospaceFont.empty()) {
-            Pango::FontDescription monoFontDesc(_pCtConfig->monospaceFont);
+            const Pango::FontDescription monoFontDesc(_pCtConfig->monospaceFont);
             int monoSize = monoFontDesc.get_size() / Pango::SCALE + (is_increase ? 1 : -1);
             if (monoSize < 6) monoSize = 6;
-            monoFontDesc.set_size(monoSize * Pango::SCALE);
 
-            _pCtConfig->monospaceFont = CtFontUtil::get_font_str(monoFontDesc);
+            _pCtConfig->monospaceFont = CtFontUtil::get_font_str(CtFontUtil::get_font_family(_pCtConfig->monospaceFont), size);
             if (auto tag = get_buffer()->get_tag_table()->lookup(CtConst::TAG_ID_MONOSPACE)) {
                 tag->property_font() = _pCtConfig->monospaceFont;
             }
         }
     }
     else if (syntaxHighlighting == CtConst::PLAIN_TEXT_ID) {
-        _pCtConfig->ptFont = CtFontUtil::get_font_str(fontDesc);
+        _pCtConfig->ptFont = CtFontUtil::get_font_str(CtFontUtil::get_font_family(_pCtConfig->ptFont), size);
         spdlog::debug("ptFont {}", _pCtConfig->ptFont);
     }
     else {
-        _pCtConfig->codeFont = CtFontUtil::get_font_str(fontDesc);
+        _pCtConfig->codeFont = CtFontUtil::get_font_str(CtFontUtil::get_font_family(_pCtConfig->codeFont), size);
         spdlog::debug("codeFont {}", _pCtConfig->codeFont);
     }
     _pCtMainWin->signal_app_apply_for_each_window([](CtMainWin* win) { win->update_theme(); });
@@ -789,7 +798,7 @@ bool CtTextView::_apply_tag_try_link(Gtk::TextIter iter_end, int offset_cursor)
             get_buffer()->select_range(iter_start, iter_end);
             Glib::ustring link_url = get_buffer()->get_text(iter_start, iter_end);
             if (not str::startswith(link_url, "htt") and !str::startswith(link_url, "ftp")) link_url = "http://" + link_url;
-            Glib::ustring property_value = std::string(CtConst::LINK_TYPE_WEBS) + CtConst::CHAR_SPACE + link_url;
+            Glib::ustring property_value = CtConst::LINK_TYPE_WEBS + CtConst::CHAR_SPACE + link_url;
             _pCtMainWin->get_ct_actions()->apply_tag(CtConst::TAG_LINK, property_value);
             tag_applied = true;
         }
