@@ -1,7 +1,7 @@
 /*
  * ct_treestore.cc
  *
- * Copyright 2009-2022
+ * Copyright 2009-2023
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -29,6 +29,8 @@
 #include "ct_actions.h"
 #include "ct_logging.h"
 
+/*static*/bool CtTreeIter::_hitExclusionFromSearch{false};
+
 CtTreeIter::CtTreeIter(Gtk::TreeIter iter, const CtTreeModelColumns* pColumns, CtMainWin* pCtMainWin)
  : Gtk::TreeIter(iter),
    _pColumns(pColumns),
@@ -95,7 +97,11 @@ bool CtTreeIter::get_node_is_bold() const
 
 bool CtTreeIter::get_node_is_excluded_from_search() const
 {
-    return (*this) and (*this)->get_value(_pColumns->colNodeIsExcludedFromSearch);
+    const bool exclude = (*this) and (*this)->get_value(_pColumns->colNodeIsExcludedFromSearch);
+    if (exclude and not _hitExclusionFromSearch) {
+        _hitExclusionFromSearch = true;
+    }
+    return exclude;
 }
 
 void CtTreeIter::set_node_is_excluded_from_search(const bool val)
@@ -105,7 +111,11 @@ void CtTreeIter::set_node_is_excluded_from_search(const bool val)
 
 bool CtTreeIter::get_node_children_are_excluded_from_search() const
 {
-    return (*this) and (*this)->get_value(_pColumns->colNodeChildrenAreExcludedFromSearch);
+    const bool exclude = (*this) and (*this)->get_value(_pColumns->colNodeChildrenAreExcludedFromSearch);
+    if (exclude and not _hitExclusionFromSearch) {
+        _hitExclusionFromSearch = true;
+    }
+    return exclude;
 }
 
 void CtTreeIter::set_node_children_are_excluded_from_search(const bool val)
@@ -241,7 +251,7 @@ void CtTreeIter::remove_all_embedded_widgets()
     }
 }
 
-std::list<CtAnchoredWidget*> CtTreeIter::get_anchored_widgets_fast(const char doSort)
+std::list<CtAnchoredWidget*> CtTreeIter::get_anchored_widgets_fast(const char doSort) const
 {
     if (*this) {
         get_node_text_buffer(); // to load buffer\widgets if not loaded
@@ -288,7 +298,7 @@ std::list<CtAnchoredWidget*> CtTreeIter::get_anchored_widgets_fast(const char do
     return std::list<CtAnchoredWidget*>{};
 }
 
-std::list<CtAnchoredWidget*> CtTreeIter::get_anchored_widgets(int start_offset/*= -1*/, int end_offset/*= -1*/)
+std::list<CtAnchoredWidget*> CtTreeIter::get_anchored_widgets(int start_offset/*= -1*/, int end_offset/*= -1*/) const
 {
     get_node_text_buffer(); // to load buffer\widgets if not loaded
     std::list<CtAnchoredWidget*> retAnchoredWidgetsList;
@@ -314,7 +324,7 @@ std::list<CtAnchoredWidget*> CtTreeIter::get_anchored_widgets(int start_offset/*
     return retAnchoredWidgetsList;
 }
 
-CtAnchoredWidget* CtTreeIter::get_anchored_widget(Glib::RefPtr<Gtk::TextChildAnchor> rChildAnchor)
+CtAnchoredWidget* CtTreeIter::get_anchored_widget(Glib::RefPtr<Gtk::TextChildAnchor> rChildAnchor) const
 {
     if (*this) {
         for (CtAnchoredWidget* pCtAnchoredWidget : (*this)->get_value(_pColumns->colAnchoredWidgets)) {
@@ -564,11 +574,11 @@ Glib::RefPtr<Gdk::Pixbuf> CtTreeStore::_get_node_icon(int nodeDepth, const std::
     Glib::RefPtr<Gdk::Pixbuf> rPixbuf;
     if (0 != customIconId) {
         // customIconId
-        rPixbuf = _pCtMainWin->get_icon_theme()->load_icon(CtConst::NODE_CUSTOM_ICONS.at((int)customIconId), CtConst::NODE_ICON_SIZE);
+        rPixbuf = _pCtMainWin->get_icon_theme()->load_icon(CtStockIcon::at(customIconId), CtConst::NODE_ICON_SIZE);
     }
     else if (CtConst::NODE_ICON_TYPE_NONE == _pCtMainWin->get_ct_config()->nodesIcons) {
         // NODE_ICON_TYPE_NONE
-        rPixbuf = _pCtMainWin->get_icon_theme()->load_icon(CtConst::NODE_CUSTOM_ICONS.at(CtConst::NODE_ICON_NO_ICON_ID), CtConst::NODE_ICON_SIZE);
+        rPixbuf = _pCtMainWin->get_icon_theme()->load_icon(CtStockIcon::at(CtConst::NODE_ICON_NO_ICON_ID), CtConst::NODE_ICON_SIZE);
     }
     else if (CtStrUtil::contains(std::array<const gchar*, 2>{CtConst::RICH_TEXT_ID, CtConst::PLAIN_TEXT_ID}, syntax.c_str())) {
         // text node
@@ -580,7 +590,7 @@ Glib::RefPtr<Gdk::Pixbuf> CtTreeStore::_get_node_icon(int nodeDepth, const std::
         }
         else {
             // NODE_ICON_TYPE_CUSTOM
-            rPixbuf = _pCtMainWin->get_icon_theme()->load_icon(CtConst::NODE_CUSTOM_ICONS.at(_pCtMainWin->get_ct_config()->defaultIconText), CtConst::NODE_ICON_SIZE);
+            rPixbuf = _pCtMainWin->get_icon_theme()->load_icon(CtStockIcon::at(_pCtMainWin->get_ct_config()->defaultIconText), CtConst::NODE_ICON_SIZE);
         }
     }
     else {
@@ -730,8 +740,8 @@ void CtTreeStore::_on_textbuffer_modified_changed(Glib::RefPtr<Gtk::TextBuffer>
 
 void CtTreeStore::_on_textbuffer_insert(const Gtk::TextBuffer::iterator& pos, const Glib::ustring& text, int /*bytes*/)
 {
-    if (_pCtMainWin->user_active() and not _pCtMainWin->get_text_view().own_insert_delete_active()) {
-        _pCtMainWin->get_text_view().text_inserted(pos, text);
+    if (_pCtMainWin->user_active() and not _pCtMainWin->get_text_view().column_edit_get_own_insert_delete_active()) {
+        _pCtMainWin->get_text_view().column_edit_text_inserted(pos, text);
         CtTreeIter currTreeIter = _pCtMainWin->curr_tree_iter();
         if (currTreeIter and currTreeIter.get_node_is_rich_text()) {
             _pCtMainWin->get_state_machine().text_variation(currTreeIter.get_node_id(), text);
@@ -741,8 +751,8 @@ void CtTreeStore::_on_textbuffer_insert(const Gtk::TextBuffer::iterator& pos, co
 
 void CtTreeStore::_on_textbuffer_erase(const Gtk::TextBuffer::iterator& range_start, const Gtk::TextBuffer::iterator& range_end)
 {
-    if (_pCtMainWin->user_active() and not _pCtMainWin->get_text_view().own_insert_delete_active()) {
-       _pCtMainWin->get_text_view().text_removed(range_start, range_end);
+    if (_pCtMainWin->user_active() and not _pCtMainWin->get_text_view().column_edit_get_own_insert_delete_active()) {
+       _pCtMainWin->get_text_view().column_edit_text_removed(range_start, range_end);
         CtTreeIter currTreeIter = _pCtMainWin->curr_tree_iter();
         if (currTreeIter and currTreeIter.get_node_is_rich_text()) {
             _pCtMainWin->get_state_machine().text_variation(currTreeIter.get_node_id(), range_start.get_text(range_end));
@@ -758,7 +768,7 @@ void CtTreeStore::_on_textbuffer_mark_set(const Gtk::TextIter& /*iter*/, const G
             if (currTreeIter and currTreeIter.get_node_is_rich_text()) {
                 _pCtMainWin->get_state_machine().update_curr_state_cursor_pos(currTreeIter.get_node_id());
             }
-            _pCtMainWin->get_text_view().selection_update();
+            _pCtMainWin->get_text_view().column_edit_selection_update();
         }
     }
 }
@@ -797,7 +807,7 @@ gint64 CtTreeStore::node_id_get(gint64 original_id, std::unordered_map<gint64,gi
     for (const auto& curr_pair : remapping_ids) {
         allocated_for_remapping_ids.insert(curr_pair.second);
     }
-    std::set<gint64> nodes_pending_rm = _pCtMainWin->get_ct_storage()->get_nodes_pending_rm();
+    const CtStorageSyncPending* pCtStorageSyncPending = _pCtMainWin->get_ct_storage()->get_storage_sync_pending();
 
     // (@txe) this function works differently from python code
     // it's easer to find max than check every id is not used through all tree
@@ -815,7 +825,7 @@ gint64 CtTreeStore::node_id_get(gint64 original_id, std::unordered_map<gint64,gi
             max_node_id = curr_id;
         }
     }
-    for (const gint64 curr_id : nodes_pending_rm) {
+    for (const gint64 curr_id : pCtStorageSyncPending->nodes_to_rm_set) {
         if (curr_id > max_node_id) {
             max_node_id = curr_id;
         }
@@ -832,7 +842,7 @@ gint64 CtTreeStore::node_id_get(gint64 original_id, std::unordered_map<gint64,gi
 
 void CtTreeStore::add_used_tags(const Glib::ustring& tags)
 {
-    std::vector<Glib::ustring> tagVec = str::split(tags, CtConst::CHAR_SPACE);
+    std::vector<Glib::ustring> tagVec = str::split(tags, " ");
     for (auto& tag : tagVec) {
         tag = str::trim(tag);
         if (not tag.empty()) {
